User prompt
make box3 next to megaUpgradeButton
User prompt
make a box2 next to the UpgradeButton
User prompt
make a box 2 next to upgradeButton
User prompt
make a box next to upgradeButton
User prompt
move the box a little longer away from the upgrade
User prompt
write next to the upgrade 50$ 1+click
User prompt
make prices for the different buttons
User prompt
make megaUpgradeButton lower down
User prompt
make another Upgrade button for 10000 that gives 20* clicking
User prompt
make upgradeButton cost 200$ and give 5* clicking
User prompt
make a upgrade button below the upgrade
User prompt
Fix Bug: 'Uncaught TypeError: Cannot read properties of undefined (reading 'anchor')' in this line: 'self.anchor.set(anchorX, anchorY);' Line Number: 54
User prompt
make a text
User prompt
make a box next to the upgrade
User prompt
make a text below the upgrade saying´ ketchup 50$ 2x click´
User prompt
make a upgrade option in the top right corner for 50$
Initial prompt
pizza clicker
===================================================================
--- original.js
+++ change.js
@@ -1,38 +1,60 @@
-/****
+/****
* Classes
****/
+// Upgrade class
+var Upgrade = Container.expand(function () {
+ var self = Container.call(this);
+ var upgradeGraphics = self.createAsset('upgrade', 'Upgrade option', 0.5, 0.5);
+ self.cost = 50; // Cost of the upgrade
+ self.onClick = function () {
+ if (LK.getScore() >= self.cost) {
+ // Deduct cost and increase pizza value
+ LK.setScore(LK.getScore() - self.cost);
+ pizza.value += 1;
+ // Update score text
+ scoreTxt.setText("$" + LK.getScore());
+ // Add a visual effect or animation if needed
+ }
+ };
+ self.update = function () {
+ // Add any updates per frame here if needed
+ };
+});
// Pizza class
var Pizza = Container.expand(function () {
- var self = Container.call(this);
- var pizzaGraphics = self.createAsset('pizza', 'Clickable pizza', 0.5, 0.5);
- self.value = 1; // Each click will earn the player $1
- self.onClick = function () {
- // Increase score
- LK.setScore(LK.getScore() + self.value);
- // Update score text
- scoreTxt.setText("$" + LK.getScore());
- // Add a visual effect or animation if needed
- };
- self.update = function () {
- // Add any updates per frame here if needed
- };
+ var self = Container.call(this);
+ var pizzaGraphics = self.createAsset('pizza', 'Clickable pizza', 0.5, 0.5);
+ self.value = 1; // Each click will earn the player $1
+ self.onClick = function () {
+ // Increase score
+ LK.setScore(LK.getScore() + self.value);
+ // Update score text
+ scoreTxt.setText("$" + LK.getScore());
+ // Add a visual effect or animation if needed
+ };
+ self.update = function () {
+ // Add any updates per frame here if needed
+ };
});
-/****
+/****
* Initialize Game
****/
var game = new LK.Game({
- backgroundColor: 0x000000 // Init game with black background
+ backgroundColor: 0x000000 // Init game with black background
});
-/****
+/****
* Game Code
****/
+var upgrade = game.addChild(new Upgrade());
+upgrade.x = 2048 - upgrade.width / 2;
+upgrade.y = upgrade.height / 2;
// Score text
var scoreTxt = new Text2('$0', {
- size: 150,
- fill: "#ffffff"
+ size: 150,
+ fill: "#ffffff"
});
scoreTxt.anchor.set(0.5, 0);
LK.gui.top.addChild(scoreTxt);
// Create pizza in the center of the screen
@@ -40,12 +62,16 @@
pizza.x = 2048 / 2;
pizza.y = 2732 / 2;
// Event listener for clicking the pizza
pizza.on('down', function (obj) {
- pizza.onClick();
+ pizza.onClick();
+}); // Event listener for clicking the upgrade option
+upgrade.on('down', function (obj) {
+ upgrade.onClick();
});
// Main game tick event
LK.on('tick', function () {
- // Update the pizza each frame
- pizza.update();
+ // Update the pizza and upgrade each frame
+ pizza.update();
+ upgrade.update();
});
// No need for additional game logic as the game is simple: click the pizza to earn money
\ No newline at end of file
hotdog with no mustard no ketchup only bread and dog. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
make a ketchup bottle. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
yellow mustard. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
Pickles. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
write 50$ on a sign. no shadow, 2D
write 200$ on a sign. no shadow, 2D
write 10000$ on a sign. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.